@@ -1,6 +1,9 @@
+import os
+import sys
+sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "../")))
 import torch.nn as nn
 from . import BasicModule
-from ..module import Embedding, RNN
+from module import Embedding, RNN
 
 
 class BiLSTM(BasicModule):
