@@ -1,9 +1,12 @@
+import os
+import sys
+sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "../")))
 from torch import nn
 from . import BasicModule
-from ..module import RNN
+from module import RNN
 from transformers import BertModel
 
-from ..utils import seq_len_to_mask
+from utils import seq_len_to_mask
 
 
 class LM(BasicModule):
